searchData={"items":[{"type":"task","title":"mix version","doc":"This module implements a mix task whose main purpose is to update the version\nnumber of an Elixir application, with extra steps such as committing a git\ntag.","ref":"Mix.Tasks.Version.html"},{"type":"task","title":"Configuration - mix version","doc":"Configuration can be provided under `:versioning` from the `project/0` callback\nof the project file:\n\n```elixir\n# in mix.exs\n\ndef project do\n  [\n    app: :my_app,\n    version: \"1.2.3\",\n    # ...\n    versioning: versioning()\n  ]\nend\n\ndefp versioning do\n  [\n    annotate:   true,\n    annotation: \"new version %s\",\n    commit_msg: \"new version %s\",\n    tag_prefix: \"v\"\n  ]\nend\n```\n\nIn the commit message and annotation, any occurence of `%s` will be replaced by\nthe new version number. The presence of `%s` is not mandatory.\n\nThis configuration is totally optional. The sample values above are the default\nvalues used by `mix version`.\n\nConfiguration can be overriden by command line options. For instance, if\n`:annotate` is set to `false` in configuration, you can use the `--annotate` CLI\nflag to force it to be `true`.","ref":"Mix.Tasks.Version.html#module-configuration"},{"type":"task","title":"Synopsis - mix version","doc":"mix version [options]","ref":"Mix.Tasks.Version.html#module-synopsis"},{"type":"task","title":"Options - mix version","doc":"* `-i, --info` - Only outputs the current version and stops. Ignores all other options. Defaults to `false`.\n* `-M, --major` - Bump to a new major version. Defaults to `false`.\n* `-m, --minor` - Bump to a new minor version. Defaults to `false`.\n* `-p, --patch` - Bump the patch version. Defaults to `false`.\n* `-n, --new-version  ` - Set the new version number. Defaults to `nil`.\n* `-a, --annotate` - Create an annotated git tag. Defaults is pulled from `mix.exs` with fallback to `true`.\n* `-c, --commit-msg  ` - Define the commit message, with all '%s' replaced by the new VSN. Defaults is pulled from `mix.exs` with fallback to `\"new version %s\"`.\n* `-A, --annotation  ` - Define the tag annotation message, with all '%s' replaced by the new VSN. Defaults is pulled from `mix.exs` with fallback to `\"new version %s\"`.\n* `-x, --tag-prefix  ` - Define the tag prefix. Defaults is pulled from `mix.exs` with fallback to `\"v\"`.\n* `-k, --tag-current` - Commit and tag with the current version. Defaults to `false`.\n* `--help` - Displays this help.","ref":"Mix.Tasks.Version.html#module-options"},{"type":"function","title":"Mix.Tasks.Version.default_opt/1","doc":"","ref":"Mix.Tasks.Version.html#default_opt/1"},{"type":"module","title":"MixVersion.Config","doc":"Helpers to read from the Mix project the app is called in.","ref":"MixVersion.Config.html"},{"type":"function","title":"MixVersion.Config.current_project/0","doc":"","ref":"MixVersion.Config.html#current_project/0"},{"type":"function","title":"MixVersion.Config.otp_app/1","doc":"","ref":"MixVersion.Config.html#otp_app/1"},{"type":"function","title":"MixVersion.Config.project_get/1","doc":"","ref":"MixVersion.Config.html#project_get/1"},{"type":"function","title":"MixVersion.Config.project_get/2","doc":"","ref":"MixVersion.Config.html#project_get/2"},{"type":"function","title":"MixVersion.Config.project_get/3","doc":"","ref":"MixVersion.Config.html#project_get/3"},{"type":"module","title":"MixVersion.Git","doc":"This module is a simple, ad-hoc interface to the Git CLI.","ref":"MixVersion.Git.html"},{"type":"function","title":"MixVersion.Git.add/2","doc":"","ref":"MixVersion.Git.html#add/2"},{"type":"function","title":"MixVersion.Git.check_tag_availability/2","doc":"","ref":"MixVersion.Git.html#check_tag_availability/2"},{"type":"function","title":"MixVersion.Git.commit/2","doc":"","ref":"MixVersion.Git.html#commit/2"},{"type":"function","title":"MixVersion.Git.get_repo/1","doc":"","ref":"MixVersion.Git.html#get_repo/1"},{"type":"function","title":"MixVersion.Git.get_unstaged/1","doc":"","ref":"MixVersion.Git.html#get_unstaged/1"},{"type":"function","title":"MixVersion.Git.installed?/0","doc":"","ref":"MixVersion.Git.html#installed?/0"},{"type":"function","title":"MixVersion.Git.path_relative_to/2","doc":"","ref":"MixVersion.Git.html#path_relative_to/2"},{"type":"function","title":"MixVersion.Git.tag/3","doc":"","ref":"MixVersion.Git.html#tag/3"},{"type":"behaviour","title":"MixVersion.Stage","doc":"Behaviour for mix version stages.","ref":"MixVersion.Stage.html"},{"type":"callback","title":"MixVersion.Stage.applies?/1","doc":"","ref":"MixVersion.Stage.html#c:applies?/1"},{"type":"callback","title":"MixVersion.Stage.run/1","doc":"","ref":"MixVersion.Stage.html#c:run/1"},{"type":"module","title":"MixVersion.Stage.ApplyHook","doc":"Stage that creates a new Git commit with the updated `mix.exs` file and all\nother changes added to the Git index.","ref":"MixVersion.Stage.ApplyHook.html"},{"type":"function","title":"MixVersion.Stage.ApplyHook.applies?/1","doc":"Callback implementation for  MixVersion.Stage.applies?/1 .","ref":"MixVersion.Stage.ApplyHook.html#applies?/1"},{"type":"function","title":"MixVersion.Stage.ApplyHook.run/2","doc":"","ref":"MixVersion.Stage.ApplyHook.html#run/2"},{"type":"module","title":"MixVersion.Stage.CheckGitTag","doc":"Stage that checks that the future Git tag does not already exist.","ref":"MixVersion.Stage.CheckGitTag.html"},{"type":"function","title":"MixVersion.Stage.CheckGitTag.applies?/1","doc":"Callback implementation for  MixVersion.Stage.applies?/1 .","ref":"MixVersion.Stage.CheckGitTag.html#applies?/1"},{"type":"function","title":"MixVersion.Stage.CheckGitTag.run/1","doc":"Callback implementation for  MixVersion.Stage.run/1 .","ref":"MixVersion.Stage.CheckGitTag.html#run/1"},{"type":"module","title":"MixVersion.Stage.CheckUnstaged","doc":"Checks if any file in the project has changes that are not committed to Git.\n\n* If the project's `mix.exs` file has unstagged changes, `mix version` will\n  abort, refusing to go any further.\n* If other files have changes, the app will prompt for confirmation to\n  continue.","ref":"MixVersion.Stage.CheckUnstaged.html"},{"type":"function","title":"MixVersion.Stage.CheckUnstaged.applies?/1","doc":"Callback implementation for  MixVersion.Stage.applies?/1 .","ref":"MixVersion.Stage.CheckUnstaged.html#applies?/1"},{"type":"function","title":"MixVersion.Stage.CheckUnstaged.run/1","doc":"Callback implementation for  MixVersion.Stage.run/1 .","ref":"MixVersion.Stage.CheckUnstaged.html#run/1"},{"type":"module","title":"MixVersion.Stage.CommitChanges","doc":"Stage that creates a new Git commit with the updated `mix.exs` file and all\nother changes added to the Git index.","ref":"MixVersion.Stage.CommitChanges.html"},{"type":"function","title":"MixVersion.Stage.CommitChanges.applies?/1","doc":"Callback implementation for  MixVersion.Stage.applies?/1 .","ref":"MixVersion.Stage.CommitChanges.html#applies?/1"},{"type":"function","title":"MixVersion.Stage.CommitChanges.run/1","doc":"Callback implementation for  MixVersion.Stage.run/1 .","ref":"MixVersion.Stage.CommitChanges.html#run/1"},{"type":"module","title":"MixVersion.Stage.DetectGitCommand","doc":"Stage that checks if the `git` command is callable with `System.cmd/3`.","ref":"MixVersion.Stage.DetectGitCommand.html"},{"type":"function","title":"MixVersion.Stage.DetectGitCommand.applies?/1","doc":"Callback implementation for  MixVersion.Stage.applies?/1 .","ref":"MixVersion.Stage.DetectGitCommand.html#applies?/1"},{"type":"function","title":"MixVersion.Stage.DetectGitCommand.run/1","doc":"Callback implementation for  MixVersion.Stage.run/1 .","ref":"MixVersion.Stage.DetectGitCommand.html#run/1"},{"type":"module","title":"MixVersion.Stage.FindGitRepo","doc":"Finds the root path of the Git repository of the project, if any.","ref":"MixVersion.Stage.FindGitRepo.html"},{"type":"function","title":"MixVersion.Stage.FindGitRepo.applies?/1","doc":"Callback implementation for  MixVersion.Stage.applies?/1 .","ref":"MixVersion.Stage.FindGitRepo.html#applies?/1"},{"type":"function","title":"MixVersion.Stage.FindGitRepo.run/1","doc":"Callback implementation for  MixVersion.Stage.run/1 .","ref":"MixVersion.Stage.FindGitRepo.html#run/1"},{"type":"module","title":"MixVersion.Stage.GetNextVsn","doc":"Decides on the new version number from the passed CLI options.","ref":"MixVersion.Stage.GetNextVsn.html"},{"type":"function","title":"MixVersion.Stage.GetNextVsn.applies?/1","doc":"Callback implementation for  MixVersion.Stage.applies?/1 .","ref":"MixVersion.Stage.GetNextVsn.html#applies?/1"},{"type":"function","title":"MixVersion.Stage.GetNextVsn.bump/2","doc":"","ref":"MixVersion.Stage.GetNextVsn.html#bump/2"},{"type":"function","title":"MixVersion.Stage.GetNextVsn.run/1","doc":"Callback implementation for  MixVersion.Stage.run/1 .","ref":"MixVersion.Stage.GetNextVsn.html#run/1"},{"type":"module","title":"MixVersion.Stage.PrintAndStop","doc":"This stage checks for the output command and prints the version and exits if\nthe flag is provided.","ref":"MixVersion.Stage.PrintAndStop.html"},{"type":"function","title":"MixVersion.Stage.PrintAndStop.applies?/1","doc":"","ref":"MixVersion.Stage.PrintAndStop.html#applies?/1"},{"type":"function","title":"MixVersion.Stage.PrintAndStop.run/1","doc":"","ref":"MixVersion.Stage.PrintAndStop.html#run/1"},{"type":"module","title":"MixVersion.Stage.TagGitHead","doc":"Stage that creates a possibly annotated tag at the current Git HEAD.","ref":"MixVersion.Stage.TagGitHead.html"},{"type":"function","title":"MixVersion.Stage.TagGitHead.applies?/1","doc":"","ref":"MixVersion.Stage.TagGitHead.html#applies?/1"},{"type":"function","title":"MixVersion.Stage.TagGitHead.run/1","doc":"","ref":"MixVersion.Stage.TagGitHead.html#run/1"},{"type":"function","title":"MixVersion.Stage.TagGitHead.tag_name/1","doc":"","ref":"MixVersion.Stage.TagGitHead.html#tag_name/1"},{"type":"module","title":"MixVersion.Stage.UpdateMixfile","doc":"Stage that is responsible to write the `mix.exs` file with the new version\nnumber.","ref":"MixVersion.Stage.UpdateMixfile.html"},{"type":"function","title":"MixVersion.Stage.UpdateMixfile.applies?/1","doc":"Callback implementation for  MixVersion.Stage.applies?/1 .","ref":"MixVersion.Stage.UpdateMixfile.html#applies?/1"},{"type":"function","title":"MixVersion.Stage.UpdateMixfile.git_enabled?/1","doc":"","ref":"MixVersion.Stage.UpdateMixfile.html#git_enabled?/1"},{"type":"function","title":"MixVersion.Stage.UpdateMixfile.run/1","doc":"Callback implementation for  MixVersion.Stage.run/1 .","ref":"MixVersion.Stage.UpdateMixfile.html#run/1"},{"type":"module","title":"MixVersion.SysCmd","doc":"Utiliy to run `System.cmd/3` with `:ok/:error` tuples results.","ref":"MixVersion.SysCmd.html"},{"type":"function","title":"MixVersion.SysCmd.exec/3","doc":"","ref":"MixVersion.SysCmd.html#exec/3"},{"type":"module","title":"MixVersion.Token","doc":"The \"token\" is the state of the command line execution, passed to and returned\nfrom all stages.","ref":"MixVersion.Token.html"},{"type":"function","title":"MixVersion.Token.new/3","doc":"","ref":"MixVersion.Token.html#new/3"},{"type":"function","title":"MixVersion.Token.put_current_vsn/2","doc":"","ref":"MixVersion.Token.html#put_current_vsn/2"},{"type":"function","title":"MixVersion.Token.put_git_cmd?/2","doc":"","ref":"MixVersion.Token.html#put_git_cmd?/2"},{"type":"function","title":"MixVersion.Token.put_git_repo/2","doc":"","ref":"MixVersion.Token.html#put_git_repo/2"},{"type":"function","title":"MixVersion.Token.put_hooks/2","doc":"","ref":"MixVersion.Token.html#put_hooks/2"},{"type":"function","title":"MixVersion.Token.put_next_vsn/2","doc":"","ref":"MixVersion.Token.html#put_next_vsn/2"},{"type":"function","title":"MixVersion.Token.put_opts/2","doc":"","ref":"MixVersion.Token.html#put_opts/2"},{"type":"type","title":"MixVersion.Token.t/0","doc":"","ref":"MixVersion.Token.html#t:t/0"}],"proglang":"elixir","content_type":"text/markdown","producer":{"name":"ex_doc","version":"0.38.2"}}